@@ -94,6 +94,26 @@ from .src import get_src
     is_flag=True,
     help="Return errors as warnings.",
 )
+@click.option(
+    "--preserve-leading-space",
+    is_flag=True,
+    help="Attempt to preserve leading space on text.",
+)
+@click.option(
+    "--preserve-blank-lines",
+    is_flag=True,
+    help="Attempt to preserve blank lines.",
+)
+@click.option(
+    "--format-css",
+    is_flag=True,
+    help="Also format contents of <style> tags.",
+)
+@click.option(
+    "--format-js",
+    is_flag=True,
+    help="Also format contents of <script> tags.",
+)
 @colorama_text(autoreset=True)
 def main(
     src: List[str],
@@ -108,6 +128,10 @@ def main(
     lint: bool,
     use_gitignore: bool,
     warn: bool,
+    preserve_leading_space: bool,
+    preserve_blank_lines: bool,
+    format_css: bool,
+    format_js: bool,
 ) -> None:
     """djLint · HTML template linter and formatter."""
     config = Config(
@@ -123,6 +147,10 @@ def main(
         check=check,
         use_gitignore=use_gitignore,
         warn=warn,
+        preserve_leading_space=preserve_leading_space,
+        preserve_blank_lines=preserve_blank_lines,
+        format_css=format_css,
+        format_js=format_js,
     )
 
     temp_file = None
@@ -228,7 +256,7 @@ def main(
 
     if temp_file and (config.reformat or config.check):
         # if using stdin, only give back formatted code.
-        echo(Path(temp_file.name).read_text(encoding="utf8").rstrip())
+        echo(Path(temp_file.name).read_text(encoding="utf8").rstrip().encode("utf8"))
 
     if temp_file:
         temp_file.close()
