@@ -12,7 +12,11 @@ def is_ignored_block_opening(config: Config, item: str) -> bool:
     """
     last_index = 0
     inline = list(
-        re.finditer(config.ignored_blocks, item, flags=re.IGNORECASE | re.VERBOSE)
+        re.finditer(
+            config.ignored_blocks,
+            item,
+            flags=re.IGNORECASE | re.VERBOSE | re.MULTILINE | re.DOTALL,
+        )
     )
 
     if inline:
@@ -29,9 +33,9 @@ def is_ignored_block_opening(config: Config, item: str) -> bool:
 
 
 def is_ignored_block_closing(config: Config, item: str) -> bool:
-    """Find ignored group opening.
+    """Find ignored group closing.
 
-    A valid ignored group opening tag will not be part of a
+    A valid ignored group closing tag will not be part of a
     single line block.
     """
     last_index = 0
@@ -64,7 +68,7 @@ def is_safe_closing_tag(config: Config, item: str) -> bool:
         re.finditer(
             re.compile(
                 config.ignored_inline_blocks + r" | " + config.ignored_blocks,
-                flags=re.IGNORECASE | re.VERBOSE,
+                flags=re.IGNORECASE | re.VERBOSE | re.MULTILINE | re.DOTALL,
             ),
             item,
         )
@@ -88,7 +92,8 @@ def inside_ignored_block(config: Config, html: str, match: re.Match) -> bool:
         for ignored_match in list(
             re.finditer(
                 re.compile(
-                    config.ignored_blocks, re.DOTALL | re.IGNORECASE | re.VERBOSE
+                    config.ignored_blocks,
+                    re.DOTALL | re.IGNORECASE | re.VERBOSE | re.MULTILINE | re.DOTALL,
                 ),
                 html,
             )
@@ -100,3 +105,21 @@ def inside_ignored_block(config: Config, html: str, match: re.Match) -> bool:
             )
         )
     )
+
+
+def inside_ignored_rule(config: Config, html: str, match: re.Match, rule: str) -> bool:
+    """Check if match is inside an ignored pattern."""
+    for rule_regex in config.ignored_rules:
+        for ignored_match in list(
+            re.finditer(
+                re.compile(rule_regex, re.DOTALL | re.IGNORECASE | re.VERBOSE),
+                html,
+            )
+        ):
+            if (
+                rule in list(set(re.split(r"\s|,", ignored_match.group(1).strip())))
+                and ignored_match.start(0) <= match.start()
+                and match.end(0) <= ignored_match.end()
+            ):
+                return True
+    return False
