@@ -191,6 +191,10 @@ class Config:
         lint: bool = False,
         use_gitignore: bool = False,
         warn: bool = False,
+        preserve_leading_space: bool = False,
+        preserve_blank_lines: bool = False,
+        format_css: bool = False,
+        format_js: bool = False,
     ):
 
         self.reformat = reformat
@@ -228,6 +232,22 @@ class Config:
             "format_attribute_template_tags", False
         )
 
+        self.preserve_leading_space: bool = (
+            preserve_leading_space
+            or djlint_settings.get("preserve_leading_space", False)
+        )
+
+        self.preserve_blank_lines: bool = preserve_blank_lines or djlint_settings.get(
+            "preserve_blank_lines", False
+        )
+
+        self.format_js: bool = format_js or djlint_settings.get("format_js", False)
+
+        self.js_config = djlint_settings.get("js")
+        self.css_config = djlint_settings.get("css")
+
+        self.format_css: bool = format_css or djlint_settings.get("format_css", False)
+
         # ignore is based on input and also profile
         self.ignore: str = str(ignore or djlint_settings.get("ignore", ""))
 
@@ -316,11 +336,18 @@ class Config:
                 x.strip() for x in extend_exclude.split(",")
             )
 
+        self.per_file_ignores = djlint_settings.get("per-file-ignores", {})
+
         # add blank line after load tags
         self.blank_line_after_tag: Optional[str] = djlint_settings.get(
             "blank_line_after_tag", None
         )
 
+        # add blank line before load tags
+        self.blank_line_before_tag: Optional[str] = djlint_settings.get(
+            "blank_line_before_tag", None
+        )
+
         # contents of tags will not be formatted
         self.ignored_block_opening: str = r"""
               <style
@@ -328,7 +355,8 @@ class Config:
             | <\?php
             | <script
             | <!--
-            | [^\{]{\#
+            | [^\{]{\#(?!\s*djlint\:\s*on)
+            | ^{\#(?!\s*djlint\:\s*on)
             | <pre
             | <textarea
             | {%[ ]*?blocktrans(?:late)?[^(?:%})]*?%}
@@ -344,7 +372,7 @@ class Config:
             | \?>
             | </script
             |  -->
-            # | \#}
+            | ^(?:(?!{\#).)*\#} # lines that have a #}, but not a {#
             | </pre
             | </textarea
             | {\#\s*djlint\:\s*on\s*\#}
@@ -554,6 +582,8 @@ class Config:
             # django/jinja/nunjucks
             | {\#\s*djlint\:\s*off\s*\#}.*?(?={\#\s*djlint\:\s*on\s*\#})
             | {%\s*comment\s*%\}\s*djlint\:off\s*\{%\s*endcomment\s*%\}.*?(?={%\s*comment\s*%\}\s*djlint\:on\s*\{%\s*endcomment\s*%\})
+            # inline jinja comments
+            | {\#(?!\s*djlint\:\s*(?:off|on)).*?\#}
             # handlebars
             | {{!--\s*djlint\:off\s*--}}.*?(?={{!--\s*djlint\:on\s*--}})
             # golang
@@ -566,6 +596,18 @@ class Config:
             | ^---[\s\S]+?---
         """
 
+        self.ignored_rules: List[str] = [
+            # html comment
+            r"<!--\s*djlint\:off(.+?)-->.*?(?=<!--\s*djlint\:on\s*-->)",
+            # django/jinja/nunjucks
+            r"{\#\s*djlint\:\s*off(.+?)\#}.*?(?={\#\s*djlint\:\s*on\s*\#})",
+            r"{%\s*comment\s*%\}\s*djlint\:off(.*?)\{%\s*endcomment\s*%\}.*?(?={%\s*comment\s*%\}\s*djlint\:on\s*\{%\s*endcomment\s*%\})",
+            # handlebars
+            r"{{!--\s*djlint\:off(.*?)--}}.*?(?={{!--\s*djlint\:on\s*--}})",
+            # golang
+            r"{{-?\s*/\*\s*djlint\:off(.*?)\*/\s*-?}}.*?(?={{-?\s*/\*\s*djlint\:on\s*\*/\s*-?}})",
+        ]
+
         self.ignored_inline_blocks: str = r"""
               <!--.*?-->
             | <(script|style).*?\</(?:\1)>
